@@ -1,28 +1,26 @@
 #!/usr/bin/env python3
 
 import os
-import sys
 import atexit
 from random import randint
 MYPATH = os.path.dirname(os.path.abspath(__file__))
-sys.path.append(os.path.dirname(MYPATH))
-import socketClient
 
-DEVICE = 'ImpiGamePro'
+try:
+    from ._app_base import AppBase
+except:
+    from _app_base import AppBase
+
+CLIENT = None
 CMD_PIPE_SEP = '<a>'
 SERVO_CENTER_VAL = 77
 
 
-def base_cmd():
-    return ['--dev', DEVICE]
-
-
 def play_game(iteration=30, devfid=None):
     global CMD_PIPE_SEP
     for _ in range(iteration):
         piped_commands = []
 
-        args = base_cmd() + ['servo sduty {} '.format(SERVO_CENTER_VAL)]
+        args = ['servo sduty {} '.format(SERVO_CENTER_VAL)]
         print("CMD: {}".format(args))
         args.append(CMD_PIPE_SEP)
         piped_commands += args
@@ -39,19 +37,19 @@ def play_game(iteration=30, devfid=None):
         piped_commands += args
 
         print("CMD PIPE: {}".format(piped_commands))
-        socketClient.run(piped_commands)
+        CLIENT.run(piped_commands)
 
 
 def deinit_servo():
     print("DEINIT SERVO, SET TO {} and DEINIT".format(SERVO_CENTER_VAL))
-    args = base_cmd() + ['servo sduty {}'.format(SERVO_CENTER_VAL)]
-    socketClient.run(args)
+    args = ['servo sduty {}'.format(SERVO_CENTER_VAL)]
+    CLIENT.run(args)
 
 
-def app(devfid=None):
-    global DEVICE
-    if devfid is not None:
-        DEVICE = devfid
+def app(devfid=None, pwd=None):
+    global CLIENT
+    CLIENT = AppBase(device=devfid, password=pwd)
+
     atexit.register(deinit_servo)
     play_game()
     deinit_servo()
