@@ -1,6 +1,4 @@
 import socket
-import sys
-
 import select
 import re
 import time
@@ -9,6 +7,22 @@ try:
 except:
     from TerminalColors import Colors as color
 
+def load_command_history(prompt_getter):
+    """Optional command history feature"""
+    try:
+        try:
+            from .micrOSClientHistory import CommandInterface
+        except:
+            from micrOSClientHistory import CommandInterface
+    except Exception as e:
+        print(f"Command history - disabled (readline module error): {e}")
+        return None
+    try:
+        return CommandInterface(prompt=prompt_getter)
+    except Exception as e:
+        print(f"Command history error: {e}")
+    return None
+
 
 class micrOSClient:
     CONN_MAP = {}
@@ -35,6 +49,10 @@ class micrOSClient:
         # Validate and resolve host (IP/Hostname)
         self.__address_manager()
 
+    @property
+    def telnet_prompt(self):
+        return f"{color.BOLD}{self.preprompt}{self.prompt}{color.NC} "
+
     def __address_manager(self):
         self.dbg_print("[INIT] micrOSClient")
         # Host is valid IP address - self.host is ip address OK
@@ -67,10 +85,22 @@ class micrOSClient:
 
     @staticmethod
     def validate_ipv4(str_in):
-        pattern = "^([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])$"
-        if bool(re.match(pattern, str_in)):
-            return True
-        return False
+        parts = str_in.split(".")
+        # An IPv4 address must have exactly 4 parts
+        if len(parts) != 4:
+            return False
+        for part in parts:
+            # Each part must be a number and not empty
+            if not part.isdigit():
+                return False
+            num = int(part)
+            # Each number must be in the valid range (0-255)
+            if num < 0 or num > 255:
+                return False
+            # Prevents leading zeros (e.g., "01" is invalid)
+            if part != str(num):
+                return False
+        return True
 
     def __connect(self, timeout):
         # Server connection - create socket
@@ -262,7 +292,7 @@ class micrOSClient:
         f_delta_t = "{}[{:.2f}]{}".format(color.OKGREEN, delta_time, color.NC)
         self.dbg_print("{}[⏰] {} {}reply: {}{}".format(f_delta_t, cmd, color.BOLD, out, color.NC))
 
-        # return output list
+        # return output list or None
         return out
 
     def send_cmd_retry(self, cmd, timeout=6, retry=5, stream=False):
@@ -281,7 +311,7 @@ class micrOSClient:
             time.sleep(0.2)
         return out
 
-    def telnet(self, timeout=4):
+    def telnet(self, timeout=5):
         """
         Implements interactive mode for socket communication.
         """
@@ -292,13 +322,32 @@ class micrOSClient:
             if "busy" in str(e) or "timed out" in str(e) or "No route to host" in str(e) or "Host is down" in str(e):
                 return
 
-        print(f"{color.BOLD}{self.preprompt}{self.prompt}{color.NC} ", end="")
+        history = load_command_history(self.telnet_prompt)              # History: Beta feature
+        print(self.telnet_prompt, end="")
+        is_empty = False                                                # Empty input support
         while True:
-            cmd = input()
-            # send command
-            output = self.send_cmd(cmd, stream=True)
-            if 'Bye!' in str(output):
+            try:
+                # INPUT HANDLING
+                cmd = input(self.telnet_prompt if is_empty else '')     # CANNOT contain prompt - it is coming back from response data
+                if len(cmd.strip()) == 0:
+                    is_empty = True
+                    continue
+                is_empty = False
+                # SEND COMMAND
+                output = self.send_cmd(cmd, timeout=timeout, stream=True)
+                if not (history is None or output is None) and "Shell: for hints type help." not in output:   # History: Beta feature
+                    history.add_history(cmd)
+                # OUTPUT HANDLING
+                if 'Bye!' in str(output):
+                    break
+                if output is None:
+                    print("Exiting... client disconnected")
+                    break
+            except KeyboardInterrupt:
+                print("Exiting...")
                 break
+        if history is not None:                                         # History: Beta feature
+            history.save_history()
         self.close()
 
     def dbg_print(self, msg, end='\n'):
@@ -325,8 +374,9 @@ class micrOSClient:
             verdict.append(console_msg)
             print(f"===>\t\t{console_msg}")
         self.close()
-        verdict.append(f"SINGLE CONNECTION LOAD TEST X{cnt}, AVERAGE REPLY TIME: {round(delta_t_all/cnt, 3)} sec\n")
-        return verdict
+        delta_t_result = round(delta_t_all / cnt, 3)
+        verdict.append(f"SINGLE CONNECTION LOAD TEST X{cnt}, AVERAGE REPLY TIME: {delta_t_result} sec\n")
+        return verdict, delta_t_result
 
     def __del__(self):
         if self.dbg and self.avg_reply[1] > 0:
@@ -355,9 +405,10 @@ def micros_connection_metrics(address):
             print(f"\t\t{_console_msg}")
             all_reply.append(_console_msg)
         success_rate = int(round(_success / cnt, 2) * 100)
-        all_reply.append(f"MULTI CONNECTION LOAD TEST X{cnt}, AVERAGE REPLY TIME: {round(_all_delta_t/cnt, 3)}s, "
-                         f"SERVER AVAILABILITY: {success_rate}% ({round(_all_delta_t/_success, 3)}s)")
-        return all_reply
+        delta_t_result = round(_all_delta_t/cnt, 3)
+        all_reply.append(f"MULTI CONNECTION LOAD TEST X{cnt}, AVERAGE REPLY TIME: {delta_t_result}s, "
+                         f"SERVER AVAILABILITY: {success_rate}% ({int((_all_delta_t/_success)*1000)} ms)")
+        return all_reply, delta_t_result
 
     # ---------------------------------------------------- #
     high_level_verdict = []
@@ -365,12 +416,12 @@ def micros_connection_metrics(address):
     # [1] Create micrOSClient object + Run LOAD tests
     com_obj = micrOSClient(host=address, port=9008, pwd="ADmin123", dbg=True)
     # [1.1] Run load test in one connection
-    verdict_list = com_obj.load_test()
+    verdict_list, delta_t_single_session = com_obj.load_test()
     com_obj.close()
     high_level_verdict.append(verdict_list[-1])
 
     # [2] Run multi connection load test - reconnect - raw connection (without retry)
-    verdict_multi = multi_conn_load(address)
+    verdict_multi, delta_t_multi_session = multi_conn_load(address)
     high_level_verdict.append((verdict_multi[-1]))
 
     ############################################################################
@@ -382,7 +433,7 @@ def micros_connection_metrics(address):
     for k in verdict_multi:
         print(f"\t{k}")
 
-    return high_level_verdict
+    return high_level_verdict, delta_t_single_session, delta_t_multi_session
 
 
 if __name__ == "__main__":
@@ -416,7 +467,7 @@ if __name__ == "__main__":
     print(f"noconf out: {noconf_mode}")
     if force_close: com_obj.close()
 
-    verdict = micros_connection_metrics(address=address)
+    verdict, delta_t_single, delta_t_multi = micros_connection_metrics(address=address)
     for k in verdict:
         print(f"+\t\t{k}")
 
